// Copyright 2021 DeepMind Technologies Limited
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include "xml/xml_numeric_format.h"

namespace mujoco {

namespace {
  thread_local int precision = 6;
}

int _mjPRIVATE__get_xml_precision() {
  return precision;
}

void _mjPRIVATE__set_xml_precision(const int new_precision) {
  precision = new_precision;
}

}  // namespace mujoco
